============
Installation
============

Sickle requires `requests <http://docs.python-requests.org/en/latest/>`_
and `lxml <http://lxml.de/>`_.


Installation using pip::

    pip install sickle


Installation using easy_install::

    easy_install sickle


